Stan Math Library: stan/math/prim/scal/fun/ub_constrain.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
ub_constrain.hpp File Reference
`#include <boost/math/tools/promotion.hpp>`
`#include <stan/math/prim/scal/fun/identity_constrain.hpp>`
`#include <cmath>`
`#include <limits>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , typename TU >
boost::math::tools::promote_args< T, TU >::type | stan::math::ub_constrain (const T x, const TU ub)
| Return the upper-bounded value for the specified unconstrained scalar and upper bound. More...
template<typename T , typename TU >
boost::math::tools::promote_args< T, TU >::type | stan::math::ub_constrain (const T x, const TU ub, T &lp)
| Return the upper-bounded value for the specified unconstrained scalar and upper bound and increment the specified log probability reference with the log absolute Jacobian determinant of the transform. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.